==> ormar-postgres-extensions-2.2.0.tar.gz: ormar-postgres-extensions-2.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

From v1.0.0 onwards, this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Pre-v1, breaking changes are indicated via a minor release, while all other changes fall under patches. At any time, you can see what's in progress for a version by filtering GitHub issues by milestone.

# [2.2.0](https://github.com/tophat/ormar-postgres-extensions/compare/v2.1.0...v2.2.0) (2022-10-04)


### Features

* JSONB Contained by ([d45a156](https://github.com/tophat/ormar-postgres-extensions/commit/d45a15658f6fb5c36136b9c1aa8ebff7488d1a6e))
* JSONB Contains ([6bf7f9a](https://github.com/tophat/ormar-postgres-extensions/commit/6bf7f9a74e9cd7edd8e328f400be5e86b630c73c))
* JSONB has key ([c80bea6](https://github.com/tophat/ormar-postgres-extensions/commit/c80bea6f9d4f5245c563b31234dc8d63e716daa3))
* JSONB has_all ([2f48df4](https://github.com/tophat/ormar-postgres-extensions/commit/2f48df4baa602e0d441ec95c8aae242e564fe38a))
* JSONB has_any ([516a6c0](https://github.com/tophat/ormar-postgres-extensions/commit/516a6c06c261942914254c3cb8a706209adab008))

# [2.1.0](https://github.com/tophat/ormar-postgres-extensions/compare/v2.0.0...v2.1.0) (2022-02-06)


### Features

* Native PG array type ([88561ad](https://github.com/tophat/ormar-postgres-extensions/commit/88561ada0bbaee4187336ceb7cce88889b635e9c))

# 1.0.0 (2021-08-03)


### Features

* Add PostgresUUID field ([181ae7b](https://github.com/tophat/ormar-postgres-extensions/commit/181ae7bd689d9bacb2041712639e859c21b6591f))
* Initial documentation ([6cdd76a](https://github.com/tophat/ormar-postgres-extensions/commit/6cdd76a24dad5806dc872ef74b257e933271604c))
* JSONB column ([3dd211e](https://github.com/tophat/ormar-postgres-extensions/commit/3dd211e90b3d7ec098f04054dcb64debc84bbc2c))

==> ormar-postgres-extensions-2.3.0.tar.gz: ormar-postgres-extensions-2.3.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

From v1.0.0 onwards, this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Pre-v1, breaking changes are indicated via a minor release, while all other changes fall under patches. At any time, you can see what's in progress for a version by filtering GitHub issues by milestone.

# [2.3.0](https://github.com/tophat/ormar-postgres-extensions/compare/v2.2.0...v2.3.0) (2022-10-05)


### Features

* CIDR type ([da8280b](https://github.com/tophat/ormar-postgres-extensions/commit/da8280ba71868fc313feca31ada5d919cd5b1468))
* INET type ([c3d2e16](https://github.com/tophat/ormar-postgres-extensions/commit/c3d2e16c4aa0cd23fb403043791629c4c01abcc8))
* MACADDR type ([553ee71](https://github.com/tophat/ormar-postgres-extensions/commit/553ee71e76ab3e3e35262241f144a833dbae561c))

# [2.2.0](https://github.com/tophat/ormar-postgres-extensions/compare/v2.1.0...v2.2.0) (2022-10-04)


### Features

* JSONB Contained by ([d45a156](https://github.com/tophat/ormar-postgres-extensions/commit/d45a15658f6fb5c36136b9c1aa8ebff7488d1a6e))
* JSONB Contains ([6bf7f9a](https://github.com/tophat/ormar-postgres-extensions/commit/6bf7f9a74e9cd7edd8e328f400be5e86b630c73c))
* JSONB has key ([c80bea6](https://github.com/tophat/ormar-postgres-extensions/commit/c80bea6f9d4f5245c563b31234dc8d63e716daa3))
* JSONB has_all ([2f48df4](https://github.com/tophat/ormar-postgres-extensions/commit/2f48df4baa602e0d441ec95c8aae242e564fe38a))
* JSONB has_any ([516a6c0](https://github.com/tophat/ormar-postgres-extensions/commit/516a6c06c261942914254c3cb8a706209adab008))

# [2.1.0](https://github.com/tophat/ormar-postgres-extensions/compare/v2.0.0...v2.1.0) (2022-02-06)


### Features

* Native PG array type ([88561ad](https://github.com/tophat/ormar-postgres-extensions/commit/88561ada0bbaee4187336ceb7cce88889b635e9c))

# 1.0.0 (2021-08-03)


### Features

* Add PostgresUUID field ([181ae7b](https://github.com/tophat/ormar-postgres-extensions/commit/181ae7bd689d9bacb2041712639e859c21b6591f))
* Initial documentation ([6cdd76a](https://github.com/tophat/ormar-postgres-extensions/commit/6cdd76a24dad5806dc872ef74b257e933271604c))
* JSONB column ([3dd211e](https://github.com/tophat/ormar-postgres-extensions/commit/3dd211e90b3d7ec098f04054dcb64debc84bbc2c))
